@@ -54,6 +54,26 @@
 
 G_DEFINE_TYPE (EmpathyAccountWidget, empathy_account_widget, G_TYPE_OBJECT)
 
+typedef enum
+{
+  NO_SERVICE = 0,
+  GTALK_SERVICE,
+  FACEBOOK_SERVICE,
+  N_SERVICES
+} Service;
+
+typedef struct
+{
+  const gchar *label_username_example;
+  gboolean show_advanced;
+} ServiceInfo;
+
+static ServiceInfo services_infos[N_SERVICES] = {
+    { "label_username_example", TRUE },
+    { "label_username_g_example", TRUE },
+    { "label_username_f_example", FALSE },
+};
+
 typedef struct {
   EmpathyAccountSettings *settings;
 
@@ -92,6 +112,10 @@ typedef struct {
   /* Used only for IRC accounts */
   EmpathyIrcNetworkChooser *irc_network_chooser;
 
+  /* Used for 'special' XMPP account having a service associated ensuring that
+   * JIDs have a specific suffix; such as Facebook for example */
+  gchar *jid_suffix;
+
   gboolean dispose_run;
 } EmpathyAccountWidgetPriv;
 
@@ -183,8 +207,17 @@ account_widget_set_control_buttons_sensitivity (EmpathyAccountWidget *self,
 
       if (sensitive)
         {
-          gtk_widget_set_can_default (priv->apply_button, TRUE);
-          gtk_widget_grab_default (priv->apply_button);
+          /* We can't grab default if the widget hasn't be packed in a
+           * window */
+          GtkWidget *window;
+
+          window = gtk_widget_get_toplevel (priv->apply_button);
+          if (window != NULL &&
+              gtk_widget_is_toplevel (window))
+            {
+              gtk_widget_set_can_default (priv->apply_button, TRUE);
+              gtk_widget_grab_default (priv->apply_button);
+            }
         }
     }
 }
@@ -1229,42 +1262,24 @@ account_widget_build_msn (EmpathyAccountWidget *self,
     }
 }
 
-static gboolean
-account_widget_is_gtalk (EmpathyAccountWidget *self)
-{
-  EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
-
-  return !tp_strdiff (empathy_account_settings_get_icon_name (priv->settings),
-      "im-google-talk");
-}
-
-static gboolean
-account_widget_is_facebook (EmpathyAccountWidget *self)
-{
-  EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
-
-  return !tp_strdiff (empathy_account_settings_get_icon_name (priv->settings),
-      "im-facebook");
-}
-
-#define FACEBOOK_SUFFIX "@chat.facebook.com"
-
 static void
-facebook_id_widget_changed_cb (GtkWidget *entry,
+suffix_id_widget_changed_cb (GtkWidget *entry,
     EmpathyAccountWidget *self)
 {
   EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
   const gchar *account;
 
+  g_assert (priv->jid_suffix != NULL);
+
   account_widget_entry_changed_common (self, GTK_ENTRY (entry), FALSE);
 
   account = empathy_account_settings_get_string (priv->settings, "account");
   if (!EMP_STR_EMPTY (account) &&
-      !g_str_has_suffix (account, FACEBOOK_SUFFIX))
+      !g_str_has_suffix (account, priv->jid_suffix))
     {
       gchar *tmp;
 
-      tmp = g_strdup_printf ("%s%s", account, FACEBOOK_SUFFIX);
+      tmp = g_strdup_printf ("%s%s", account, priv->jid_suffix);
 
       DEBUG ("Change account from '%s' to '%s'", account, tmp);
 
@@ -1276,17 +1291,23 @@ facebook_id_widget_changed_cb (GtkWidget *entry,
 }
 
 static gchar *
-remove_facebook_suffix (const gchar *str)
+remove_jid_suffix (EmpathyAccountWidget *self,
+    const gchar *str)
 {
-  if (!g_str_has_suffix (str, FACEBOOK_SUFFIX))
+  EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
+
+  g_assert (priv->jid_suffix != NULL);
+
+  if (!g_str_has_suffix (str, priv->jid_suffix))
     return g_strdup (str);
 
-  return g_strndup (str, strlen (str) - strlen (FACEBOOK_SUFFIX));
+  return g_strndup (str, strlen (str) - strlen (priv->jid_suffix));
 }
 
 static void
-setup_facebook_id_widget (EmpathyAccountWidget *self,
-    GtkWidget *widget)
+setup_id_widget_with_suffix (EmpathyAccountWidget *self,
+    GtkWidget *widget,
+    const gchar *suffix)
 {
   EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
   const gchar *str = NULL;
@@ -1294,12 +1315,15 @@ setup_facebook_id_widget (EmpathyAccountWidget *self,
   g_object_set_data_full (G_OBJECT (widget), "param_name",
       g_strdup ("account"), g_free);
 
+  g_assert (priv->jid_suffix == NULL);
+  priv->jid_suffix = g_strdup (suffix);
+
   str = empathy_account_settings_get_string (priv->settings, "account");
   if (str != NULL)
     {
       gchar *tmp;
 
-      tmp = remove_facebook_suffix (str);
+      tmp = remove_jid_suffix (self, str);
       gtk_entry_set_text (GTK_ENTRY (widget), tmp);
       g_free (tmp);
     }
@@ -1307,7 +1331,29 @@ setup_facebook_id_widget (EmpathyAccountWidget *self,
   priv->param_account_widget = widget;
 
   g_signal_connect (widget, "changed",
-      G_CALLBACK (facebook_id_widget_changed_cb), self);
+      G_CALLBACK (suffix_id_widget_changed_cb), self);
+}
+
+static Service
+account_widget_get_service (EmpathyAccountWidget *self)
+{
+  EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
+  const gchar *icon_name, *service;
+
+  icon_name = empathy_account_settings_get_icon_name (priv->settings);
+  service = empathy_account_settings_get_service (priv->settings);
+
+  /* Previous versions of Empathy didn't set the Service property on Facebook
+   * and gtalk accounts, so we check using the icon name as well. */
+  if (!tp_strdiff (icon_name, "im-google-talk") ||
+      !tp_strdiff (service, "google-talk"))
+    return GTALK_SERVICE;
+
+  if (!tp_strdiff (icon_name, "im-facebook") ||
+      !tp_strdiff (service, "facebook"))
+    return FACEBOOK_SERVICE;
+
+  return NO_SERVICE;
 }
 
 static void
@@ -1319,18 +1365,18 @@ account_widget_build_jabber (EmpathyAccountWidget *self,
   GtkWidget *checkbutton_ssl;
   GtkWidget *label_id, *label_password;
   GtkWidget *label_id_create, *label_password_create;
-  GtkWidget *label_example_gtalk, *label_example_jabber, *label_example_fb;
-  gboolean is_gtalk, is_facebook;
+  GtkWidget *label_example_fb;
+  GtkWidget *label_example;
   GtkWidget *expander_advanced;
   GtkWidget *entry_id;
+  Service service;
 
-  is_gtalk = account_widget_is_gtalk (self);
-  is_facebook = account_widget_is_facebook (self);
+  service = account_widget_get_service (self);
 
   empathy_account_settings_set_regex (priv->settings, "account",
       ACCOUNT_REGEX_JABBER);
 
-  if (priv->simple && !is_gtalk && !is_facebook)
+  if (priv->simple && service == NO_SERVICE)
     {
       /* Simple widget for XMPP */
       self->ui_details->gui = empathy_builder_get_file (filename,
@@ -1356,7 +1402,7 @@ account_widget_build_jabber (EmpathyAccountWidget *self,
 
       self->ui_details->default_focus = g_strdup ("entry_id_simple");
     }
-  else if (priv->simple && is_gtalk)
+  else if (priv->simple && service == GTALK_SERVICE)
     {
       /* Simple widget for Google Talk */
       self->ui_details->gui = empathy_builder_get_file (filename,
@@ -1370,7 +1416,7 @@ account_widget_build_jabber (EmpathyAccountWidget *self,
 
       self->ui_details->default_focus = g_strdup ("entry_id_g_simple");
     }
-  else if (priv->simple && is_facebook)
+  else if (priv->simple && service == FACEBOOK_SERVICE)
     {
       /* Simple widget for Facebook */
       self->ui_details->gui = empathy_builder_get_file (filename,
@@ -1382,21 +1428,22 @@ account_widget_build_jabber (EmpathyAccountWidget *self,
           "entry_password_fb_simple", "password",
           NULL);
 
-      setup_facebook_id_widget (self, entry_id);
+      setup_id_widget_with_suffix (self, entry_id, "@chat.facebook.com");
 
       self->ui_details->default_focus = g_strdup ("entry_id_fb_simple");
     }
   else
     {
+      ServiceInfo info = services_infos[service];
+
       /* Full widget for XMPP, Google Talk and Facebook*/
       self->ui_details->gui = empathy_builder_get_file (filename,
           "table_common_settings", &priv->table_common_settings,
           "vbox_jabber_settings", &self->ui_details->widget,
           "spinbutton_port", &spinbutton_port,
           "checkbutton_ssl", &checkbutton_ssl,
-          "label_username_example", &label_example_jabber,
-          "label_username_g_example", &label_example_gtalk,
           "label_username_f_example", &label_example_fb,
+          info.label_username_example, &label_example,
           "expander_advanced", &expander_advanced,
           "entry_id", &entry_id,
           "label_id", &label_id,
@@ -1413,13 +1460,13 @@ account_widget_build_jabber (EmpathyAccountWidget *self,
           "checkbutton_encryption", "require-encryption",
           NULL);
 
-      if (is_facebook)
+      if (service == FACEBOOK_SERVICE)
         {
           gtk_label_set_label (GTK_LABEL (label_id), _("Username:"));
 
           /* Facebook special case the entry ID widget to hide the
            * "@chat.facebook.com" part */
-          setup_facebook_id_widget (self, entry_id);
+          setup_id_widget_with_suffix (self, entry_id, "@chat.facebook.com");
         }
       else
         {
@@ -1433,28 +1480,23 @@ account_widget_build_jabber (EmpathyAccountWidget *self,
           G_CALLBACK (account_widget_jabber_ssl_toggled_cb),
           self);
 
-      if (is_gtalk)
-        {
-          gtk_widget_hide (label_example_jabber);
-          gtk_widget_show (label_example_gtalk);
-        }
-      else if (is_facebook)
+      if (service == FACEBOOK_SERVICE)
         {
           GtkContainer *parent;
           GList *children;
 
-          gtk_widget_hide (label_example_jabber);
-
           /* Removing the label from list of focusable widgets */
           parent = GTK_CONTAINER (gtk_widget_get_parent (label_example_fb));
           children = gtk_container_get_children (parent);
           children = g_list_remove (children, label_example_fb);
           gtk_container_set_focus_chain (parent, children);
           g_list_free (children);
-
-          gtk_widget_show (label_example_fb);
-          gtk_widget_hide (expander_advanced);
         }
+
+      gtk_widget_show (label_example);
+
+      if (!info.show_advanced)
+        gtk_widget_hide (expander_advanced);
     }
 }
 
@@ -1926,7 +1968,7 @@ add_register_buttons (EmpathyAccountWidget *self,
   if (!tp_connection_manager_protocol_can_register (protocol))
     return;
 
-  if (account_widget_is_gtalk (self) || account_widget_is_facebook (self))
+  if (account_widget_get_service (self) != NO_SERVICE)
     return;
 
   if (priv->simple)
@@ -2168,10 +2210,13 @@ static void
 do_finalize (GObject *obj)
 {
   EmpathyAccountWidget *self = EMPATHY_ACCOUNT_WIDGET (obj);
+  EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
 
   g_free (self->ui_details->default_focus);
   g_slice_free (EmpathyAccountWidgetUIDetails, self->ui_details);
 
+  g_free (priv->jid_suffix);
+
   if (G_OBJECT_CLASS (empathy_account_widget_parent_class)->finalize != NULL)
     G_OBJECT_CLASS (empathy_account_widget_parent_class)->finalize (obj);
 }
@@ -2322,9 +2367,11 @@ empathy_account_widget_get_default_display_name (EmpathyAccountWidget *self)
   const gchar *login_id;
   const gchar *protocol, *p;
   gchar *default_display_name;
+  Service service;
 
   login_id = empathy_account_settings_get_string (priv->settings, "account");
   protocol = empathy_account_settings_get_protocol (priv->settings);
+  service = account_widget_get_service (self);
 
   if (login_id != NULL)
     {
@@ -2345,11 +2392,11 @@ empathy_account_widget_get_default_display_name (EmpathyAccountWidget *self)
           default_display_name = g_strdup_printf (_("%1$s on %2$s"),
               login_id, empathy_irc_network_get_name (network));
         }
-      else if (account_widget_is_facebook (self))
+      else if (service == FACEBOOK_SERVICE)
         {
           gchar *tmp;
 
-          tmp = remove_facebook_suffix (login_id);
+          tmp = remove_jid_suffix (self, login_id);
           default_display_name = g_strdup_printf ("Facebook (%s)", tmp);
           g_free (tmp);
         }
