@@ -377,14 +377,14 @@ real_drag_individual_received_cb (EmpathyIndividualView *self,
   if (!tp_strdiff (new_group, EMPATHY_INDIVIDUAL_STORE_FAVORITE))
     {
       /* Mark contact as favourite */
-      folks_favourite_set_is_favourite (FOLKS_FAVOURITE (individual), TRUE);
+      folks_favouritable_set_is_favourite (FOLKS_FAVOURITABLE (individual), TRUE);
       return;
     }
 
   if (!tp_strdiff (old_group, EMPATHY_INDIVIDUAL_STORE_FAVORITE))
     {
       /* Remove contact as favourite */
-      folks_favourite_set_is_favourite (FOLKS_FAVOURITE (individual), FALSE);
+      folks_favouritable_set_is_favourite (FOLKS_FAVOURITABLE (individual), FALSE);
 
       /* Don't try to remove it */
       old_group = NULL;
@@ -681,7 +681,7 @@ individual_view_drag_motion (GtkWidget *widget,
         }
 
       if (individual != NULL &&
-          folks_presence_is_online (FOLKS_PRESENCE (individual)) &&
+          folks_has_presence_is_online (FOLKS_HAS_PRESENCE (individual)) &&
           (caps & EMPATHY_CAPABILITIES_FT))
         {
           gdk_drag_status (context, GDK_ACTION_COPY, time_);
@@ -900,7 +900,6 @@ individual_view_popup_menu_idle_cb (gpointer user_data)
 
   if (menu != NULL)
     {
-      g_signal_connect (menu, "deactivate", G_CALLBACK (gtk_menu_detach), NULL);
       gtk_menu_attach_to_widget (GTK_MENU (menu), GTK_WIDGET (data->view),
           NULL);
       gtk_widget_show (menu);
@@ -1032,7 +1031,6 @@ individual_view_call_activated_cb (EmpathyCellRendererActivatable *cell,
   gtk_menu_shell_append (shell, item);
   gtk_widget_show (item);
 
-  g_signal_connect (menu, "deactivate", G_CALLBACK (gtk_menu_detach), NULL);
   gtk_menu_attach_to_widget (GTK_MENU (menu), GTK_WIDGET (view), NULL);
   gtk_widget_show (menu);
   gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL,
@@ -2347,12 +2345,45 @@ individual_view_remove_activate_cb (GtkMenuItem *menuitem,
     {
       gchar *text;
       GtkWindow *parent;
+      GList *l, *personas;
+      guint persona_count = 0;
+
+      personas = folks_individual_get_personas (individual);
+
+      /* If we have more than one TpfPersona, display a different message
+       * ensuring the user knows that *all* of the meta-contacts' personas will
+       * be removed. */
+      for (l = personas; l != NULL; l = l->next)
+        {
+          if (!TPF_IS_PERSONA (l->data))
+            continue;
+
+          persona_count++;
+          if (persona_count >= 2)
+            break;
+        }
+
+      if (persona_count < 2)
+        {
+          /* Not a meta-contact */
+          text =
+              g_strdup_printf (
+                  _("Do you really want to remove the contact '%s'?"),
+                  folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)));
+        }
+      else
+        {
+          /* Meta-contact */
+          text =
+              g_strdup_printf (
+                  _("Do you really want to remove the linked contact '%s'? "
+                    "Note that this will remove all the contacts which make up "
+                    "this linked contact."),
+                  folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)));
+        }
 
       parent = empathy_get_toplevel_window (GTK_WIDGET (view));
-      text =
-          g_strdup_printf (_
-          ("Do you really want to remove the contact '%s'?"),
-          folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)));
+
       if (individual_view_remove_dialog_show (parent, _("Removing contact"),
               text))
         {
