@@ -26,8 +26,6 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#include <telepathy-glib/debug-sender.h>
-
 #define DEBUG_FLAG EMPATHY_DEBUG_TLS
 #include <libempathy/empathy-debug.h>
 #include <libempathy/empathy-auth-factory.h>
@@ -191,7 +189,6 @@ auth_factory_new_tls_handler_cb (EmpathyAuthFactory *factory,
 {
   EmpathyTLSCertificate *certificate = NULL;
   gchar *hostname = NULL;
-  gchar **reference_identities = NULL;
   EmpathyTLSVerifier *verifier;
 
   DEBUG ("New TLS server handler received from the factory");
@@ -199,18 +196,15 @@ auth_factory_new_tls_handler_cb (EmpathyAuthFactory *factory,
   g_object_get (handler,
       "certificate", &certificate,
       "hostname", &hostname,
-      "reference-identities", &reference_identities,
       NULL);
 
-  verifier = empathy_tls_verifier_new (certificate, hostname,
-      (const gchar **) reference_identities);
+  verifier = empathy_tls_verifier_new (certificate, hostname);
   empathy_tls_verifier_verify_async (verifier,
       verifier_verify_cb, NULL);
 
   g_object_unref (verifier);
   g_object_unref (certificate);
   g_free (hostname);
-  g_strfreev (reference_identities);
 }
 
 static void
@@ -237,7 +231,6 @@ main (int argc,
   GOptionContext *context;
   GError *error = NULL;
   EmpathyAuthFactory *factory;
-  TpDebugSender *debug_sender;
 
   g_thread_init (NULL);
 
@@ -262,12 +255,6 @@ main (int argc,
   gtk_window_set_default_icon_name ("empathy");
   textdomain (GETTEXT_PACKAGE);
 
-#ifdef ENABLE_DEBUG
-  /* Set up debug sender */
-  debug_sender = tp_debug_sender_dup ();
-  g_log_set_default_handler (tp_debug_sender_log_handler, G_LOG_DOMAIN);
-#endif
-
   factory = empathy_auth_factory_dup_singleton ();
 
   g_signal_connect (factory, "new-server-tls-handler",
@@ -299,7 +286,6 @@ main (int argc,
   gtk_main ();
 
   g_object_unref (factory);
-  g_object_unref (debug_sender);
 
   return EXIT_SUCCESS;
 }
